==> libxkbcommon-doc-1.12.2-1-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/all_2.js <==
var searchData=
[
  ['2_20–_202013_2011_2022_0',['libxkbcommon 0.3.2 – 2013-11-22',['../release-notes.html#libxkbcommon-032--2013-11-22',1,'']]],
  ['2_20–_202014_2005_2015_1',['libxkbcommon 0.4.2 – 2014-05-15',['../release-notes.html#libxkbcommon-042--2014-05-15',1,'']]],
  ['2_20–_202017_2008_2004_2',['libxkbcommon 0.7.2 – 2017-08-04',['../release-notes.html#libxkbcommon-072--2017-08-04',1,'']]],
  ['2_20–_202018_2008_2005_3',['libxkbcommon 0.8.2 – 2018-08-05',['../release-notes.html#libxkbcommon-082--2018-08-05',1,'']]],
  ['2_20–_202020_2011_2020_4',['libxkbcommon 1.0.2 – 2020-11-20',['../release-notes.html#libxkbcommon-102--2020-11-20',1,'']]],
  ['2_20–_202025_2005_2007_5',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.2&quot;&gt;1.9.2&lt;/a&gt; – 2025-05-07',['../release-notes.html#libxkbcommon-192--2025-05-07',1,'']]],
  ['2_20–_202025_2010_2020_6',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2&quot;&gt;1.12.2&lt;/a&gt; – 2025-10-20',['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'']]],
  ['2_200_20–_202021_2004_2003_7',['libxkbcommon 1.2.0 – 2021-04-03',['../release-notes.html#libxkbcommon-120--2021-04-03',1,'']]],
  ['2_201_20–_202021_2004_2007_8',['libxkbcommon 1.2.1 – 2021-04-07',['../release-notes.html#libxkbcommon-121--2021-04-07',1,'']]],
  ['20_9',['20',['../release-notes.html#libxkbcommon-102--2020-11-20',1,'libxkbcommon 1.0.2 – 2020-11-20'],['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'libxkbcommon <a href="https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2">1.12.2</a> – 2025-10-20']]],
  ['2013_2004_2001_10',['libxkbcommon 0.3.0 – 2013-04-01',['../release-notes.html#libxkbcommon-030--2013-04-01',1,'']]],
  ['2013_2006_2003_11',['libxkbcommon 0.3.1 – 2013-06-03',['../release-notes.html#libxkbcommon-031--2013-06-03',1,'']]],
  ['2013_2011_2022_12',['libxkbcommon 0.3.2 – 2013-11-22',['../release-notes.html#libxkbcommon-032--2013-11-22',1,'']]],
  ['2014_2002_2002_13',['libxkbcommon 0.4.0 – 2014-02-02',['../release-notes.html#libxkbcommon-040--2014-02-02',1,'']]],
  ['2014_2003_2027_14',['libxkbcommon 0.4.1 – 2014-03-27',['../release-notes.html#libxkbcommon-041--2014-03-27',1,'']]],
  ['2014_2005_2015_15',['libxkbcommon 0.4.2 – 2014-05-15',['../release-notes.html#libxkbcommon-042--2014-05-15',1,'']]],
  ['2014_2008_2019_16',['libxkbcommon 0.4.3 – 2014-08-19',['../release-notes.html#libxkbcommon-043--2014-08-19',1,'']]],
  ['2014_2010_2018_17',['libxkbcommon 0.5.0 – 2014-10-18',['../release-notes.html#libxkbcommon-050--2014-10-18',1,'']]],
  ['2016_2003_2016_18',['libxkbcommon 0.6.0 – 2016-03-16',['../release-notes.html#libxkbcommon-060--2016-03-16',1,'']]],
  ['2016_2004_2008_19',['libxkbcommon 0.6.1 – 2016-04-08',['../release-notes.html#libxkbcommon-061--2016-04-08',1,'']]],
  ['2016_2011_2011_20',['libxkbcommon 0.7.0 – 2016-11-11',['../release-notes.html#libxkbcommon-070--2016-11-11',1,'']]],
  ['2017_2001_2018_21',['libxkbcommon 0.7.1 – 2017-01-18',['../release-notes.html#libxkbcommon-071--2017-01-18',1,'']]],
  ['2017_2008_2004_22',['libxkbcommon 0.7.2 – 2017-08-04',['../release-notes.html#libxkbcommon-072--2017-08-04',1,'']]],
  ['2017_2012_2015_23',['libxkbcommon 0.8.0 – 2017-12-15',['../release-notes.html#libxkbcommon-080--2017-12-15',1,'']]],
  ['2018_2008_2003_24',['libxkbcommon 0.8.1 – 2018-08-03',['../release-notes.html#libxkbcommon-081--2018-08-03',1,'']]],
  ['2018_2008_2005_25',['libxkbcommon 0.8.2 – 2018-08-05',['../release-notes.html#libxkbcommon-082--2018-08-05',1,'']]],
  ['2019_2002_2008_26',['libxkbcommon 0.8.3 – 2019-02-08',['../release-notes.html#libxkbcommon-083--2019-02-08',1,'']]],
  ['2019_2002_2022_27',['libxkbcommon 0.8.4 – 2019-02-22',['../release-notes.html#libxkbcommon-084--2019-02-22',1,'']]],
  ['2019_2010_2019_28',['2019 10 19',['../release-notes.html#libxkbcommon-090--2019-10-19',1,'libxkbcommon 0.9.0 – 2019-10-19'],['../release-notes.html#libxkbcommon-091--2019-10-19',1,'libxkbcommon 0.9.1 – 2019-10-19']]],
  ['2020_2001_2018_29',['libxkbcommon 0.10.0 – 2020-01-18',['../release-notes.html#libxkbcommon-0100--2020-01-18',1,'']]],
  ['2020_2009_2005_30',['libxkbcommon 1.0.0 – 2020-09-05',['../release-notes.html#libxkbcommon-100--2020-09-05',1,'']]],
  ['2020_2009_2011_31',['libxkbcommon 1.0.1 – 2020-09-11',['../release-notes.html#libxkbcommon-101--2020-09-11',1,'']]],
  ['2020_2011_2020_32',['libxkbcommon 1.0.2 – 2020-11-20',['../release-notes.html#libxkbcommon-102--2020-11-20',1,'']]],
  ['2020_2011_2023_33',['libxkbcommon 1.0.3 – 2020-11-23',['../release-notes.html#libxkbcommon-103--2020-11-23',1,'']]],
  ['2021_2002_2027_34',['libxkbcommon 1.1.0 – 2021-02-27',['../release-notes.html#libxkbcommon-110--2021-02-27',1,'']]],
  ['2021_2004_2003_35',['libxkbcommon 1.2.0 – 2021-04-03',['../release-notes.html#libxkbcommon-120--2021-04-03',1,'']]],
  ['2021_2004_2007_36',['libxkbcommon 1.2.1 – 2021-04-07',['../release-notes.html#libxkbcommon-121--2021-04-07',1,'']]],
  ['2021_2005_2001_37',['libxkbcommon 1.3.0 – 2021-05-01',['../release-notes.html#libxkbcommon-130--2021-05-01',1,'']]],
  ['2021_2009_2010_38',['libxkbcommon 1.3.1 – 2021-09-10',['../release-notes.html#libxkbcommon-131--2021-09-10',1,'']]],
  ['2022_2002_2004_39',['libxkbcommon 1.4.0 – 2022-02-04',['../release-notes.html#libxkbcommon-140--2022-02-04',1,'']]],
  ['2022_2005_2021_40',['libxkbcommon 1.4.1 – 2022-05-21',['../release-notes.html#libxkbcommon-141--2022-05-21',1,'']]],
  ['2023_2001_2002_41',['libxkbcommon 1.5.0 – 2023-01-02',['../release-notes.html#libxkbcommon-150--2023-01-02',1,'']]],
  ['2023_2010_2008_42',['libxkbcommon 1.6.0 – 2023-10-08',['../release-notes.html#libxkbcommon-160--2023-10-08',1,'']]],
  ['2024_2003_2024_43',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.7.0&quot;&gt;1.7.0&lt;/a&gt; – 2024-03-24',['../release-notes.html#libxkbcommon-170--2024-03-24',1,'']]],
  ['2025_2002_2004_44',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.8.0&quot;&gt;1.8.0&lt;/a&gt; – 2025-02-04',['../release-notes.html#libxkbcommon-180--2025-02-04',1,'']]],
  ['2025_2003_2012_45',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.8.1&quot;&gt;1.8.1&lt;/a&gt; – 2025-03-12',['../release-notes.html#libxkbcommon-181--2025-03-12',1,'']]],
  ['2025_2004_2026_46',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.0&quot;&gt;1.9.0&lt;/a&gt; – 2025-04-26',['../release-notes.html#libxkbcommon-190--2025-04-26',1,'']]],
  ['2025_2005_2002_47',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.1&quot;&gt;1.9.1&lt;/a&gt; – 2025-05-02',['../release-notes.html#libxkbcommon-191--2025-05-02',1,'']]],
  ['2025_2005_2007_48',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.2&quot;&gt;1.9.2&lt;/a&gt; – 2025-05-07',['../release-notes.html#libxkbcommon-192--2025-05-07',1,'']]],
  ['2025_2005_2021_49',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.10.0&quot;&gt;1.10.0&lt;/a&gt; – 2025-05-21',['../release-notes.html#libxkbcommon-1100--2025-05-21',1,'']]],
  ['2025_2008_2008_50',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.11.0&quot;&gt;1.11.0&lt;/a&gt; – 2025-08-08',['../release-notes.html#libxkbcommon-1110--2025-08-08',1,'']]],
  ['2025_2010_2010_51',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.0&quot;&gt;1.12.0&lt;/a&gt; – 2025-10-10',['../release-notes.html#libxkbcommon-1120--2025-10-10',1,'']]],
  ['2025_2010_2017_52',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.1&quot;&gt;1.12.1&lt;/a&gt; – 2025-10-17',['../release-notes.html#libxkbcommon-1121--2025-10-17',1,'']]],
  ['2025_2010_2020_53',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2&quot;&gt;1.12.2&lt;/a&gt; – 2025-10-20',['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'']]],
  ['203_20–_20invalid_20include_20statement_54',['XKB-203 – Invalid include statement',['../error-index.html#XKB-203',1,'']]],
  ['206_20–_20invalid_20modmap_20entry_55',['XKB-206 – Invalid modmap entry',['../error-index.html#XKB-206',1,'']]],
  ['21_56',['21',['../release-notes.html#libxkbcommon-141--2022-05-21',1,'libxkbcommon 1.4.1 – 2022-05-21'],['../release-notes.html#libxkbcommon-1100--2025-05-21',1,'libxkbcommon <a href="https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.10.0">1.10.0</a> – 2025-05-21']]],
  ['22_57',['22',['../release-notes.html#libxkbcommon-032--2013-11-22',1,'libxkbcommon 0.3.2 – 2013-11-22'],['../release-notes.html#libxkbcommon-084--2019-02-22',1,'libxkbcommon 0.8.4 – 2019-02-22']]],
  ['23_58',['libxkbcommon 1.0.3 – 2020-11-23',['../release-notes.html#libxkbcommon-103--2020-11-23',1,'']]],
  ['237_20–_20unsupported_20group_20index_59',['XKB-237 – Unsupported group index',['../error-index.html#XKB-237',1,'']]],
  ['239_20–_20conflicting_20key_20type_20level_20names_60',['XKB-239 – Conflicting key type level names',['../error-index.html#XKB-239',1,'']]],
  ['24_61',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.7.0&quot;&gt;1.7.0&lt;/a&gt; – 2024-03-24',['../release-notes.html#libxkbcommon-170--2024-03-24',1,'']]],
  ['254_20–_20invalid_20set_20default_20statement_62',['XKB-254 – Invalid set default statement',['../error-index.html#XKB-254',1,'']]],
  ['26_63',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.0&quot;&gt;1.9.0&lt;/a&gt; – 2025-04-26',['../release-notes.html#libxkbcommon-190--2025-04-26',1,'']]],
  ['266_20–_20conflicting_20key_20type_20map_20entry_64',['XKB-266 – Conflicting key type map entry',['../error-index.html#XKB-266',1,'']]],
  ['27_65',['27',['../release-notes.html#libxkbcommon-041--2014-03-27',1,'libxkbcommon 0.4.1 – 2014-03-27'],['../release-notes.html#libxkbcommon-110--2021-02-27',1,'libxkbcommon 1.1.0 – 2021-02-27']]],
  ['286_20–_20undefined_20key_20type_66',['XKB-286 – Undefined key type',['../error-index.html#XKB-286',1,'']]]
];

==> libxkbcommon-doc-1.12.3-1-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/all_2.js <==
var searchData=
[
  ['2_20–_202013_2011_2022_0',['libxkbcommon 0.3.2 – 2013-11-22',['../release-notes.html#libxkbcommon-032--2013-11-22',1,'']]],
  ['2_20–_202014_2005_2015_1',['libxkbcommon 0.4.2 – 2014-05-15',['../release-notes.html#libxkbcommon-042--2014-05-15',1,'']]],
  ['2_20–_202017_2008_2004_2',['libxkbcommon 0.7.2 – 2017-08-04',['../release-notes.html#libxkbcommon-072--2017-08-04',1,'']]],
  ['2_20–_202018_2008_2005_3',['libxkbcommon 0.8.2 – 2018-08-05',['../release-notes.html#libxkbcommon-082--2018-08-05',1,'']]],
  ['2_20–_202020_2011_2020_4',['libxkbcommon 1.0.2 – 2020-11-20',['../release-notes.html#libxkbcommon-102--2020-11-20',1,'']]],
  ['2_20–_202025_2005_2007_5',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.2&quot;&gt;1.9.2&lt;/a&gt; – 2025-05-07',['../release-notes.html#libxkbcommon-192--2025-05-07',1,'']]],
  ['2_20–_202025_2010_2020_6',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2&quot;&gt;1.12.2&lt;/a&gt; – 2025-10-20',['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'']]],
  ['2_200_20–_202021_2004_2003_7',['libxkbcommon 1.2.0 – 2021-04-03',['../release-notes.html#libxkbcommon-120--2021-04-03',1,'']]],
  ['2_201_20–_202021_2004_2007_8',['libxkbcommon 1.2.1 – 2021-04-07',['../release-notes.html#libxkbcommon-121--2021-04-07',1,'']]],
  ['20_9',['20',['../release-notes.html#libxkbcommon-102--2020-11-20',1,'libxkbcommon 1.0.2 – 2020-11-20'],['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'libxkbcommon <a href="https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2">1.12.2</a> – 2025-10-20']]],
  ['2013_2004_2001_10',['libxkbcommon 0.3.0 – 2013-04-01',['../release-notes.html#libxkbcommon-030--2013-04-01',1,'']]],
  ['2013_2006_2003_11',['libxkbcommon 0.3.1 – 2013-06-03',['../release-notes.html#libxkbcommon-031--2013-06-03',1,'']]],
  ['2013_2011_2022_12',['libxkbcommon 0.3.2 – 2013-11-22',['../release-notes.html#libxkbcommon-032--2013-11-22',1,'']]],
  ['2014_2002_2002_13',['libxkbcommon 0.4.0 – 2014-02-02',['../release-notes.html#libxkbcommon-040--2014-02-02',1,'']]],
  ['2014_2003_2027_14',['libxkbcommon 0.4.1 – 2014-03-27',['../release-notes.html#libxkbcommon-041--2014-03-27',1,'']]],
  ['2014_2005_2015_15',['libxkbcommon 0.4.2 – 2014-05-15',['../release-notes.html#libxkbcommon-042--2014-05-15',1,'']]],
  ['2014_2008_2019_16',['libxkbcommon 0.4.3 – 2014-08-19',['../release-notes.html#libxkbcommon-043--2014-08-19',1,'']]],
  ['2014_2010_2018_17',['libxkbcommon 0.5.0 – 2014-10-18',['../release-notes.html#libxkbcommon-050--2014-10-18',1,'']]],
  ['2016_2003_2016_18',['libxkbcommon 0.6.0 – 2016-03-16',['../release-notes.html#libxkbcommon-060--2016-03-16',1,'']]],
  ['2016_2004_2008_19',['libxkbcommon 0.6.1 – 2016-04-08',['../release-notes.html#libxkbcommon-061--2016-04-08',1,'']]],
  ['2016_2011_2011_20',['libxkbcommon 0.7.0 – 2016-11-11',['../release-notes.html#libxkbcommon-070--2016-11-11',1,'']]],
  ['2017_2001_2018_21',['libxkbcommon 0.7.1 – 2017-01-18',['../release-notes.html#libxkbcommon-071--2017-01-18',1,'']]],
  ['2017_2008_2004_22',['libxkbcommon 0.7.2 – 2017-08-04',['../release-notes.html#libxkbcommon-072--2017-08-04',1,'']]],
  ['2017_2012_2015_23',['libxkbcommon 0.8.0 – 2017-12-15',['../release-notes.html#libxkbcommon-080--2017-12-15',1,'']]],
  ['2018_2008_2003_24',['libxkbcommon 0.8.1 – 2018-08-03',['../release-notes.html#libxkbcommon-081--2018-08-03',1,'']]],
  ['2018_2008_2005_25',['libxkbcommon 0.8.2 – 2018-08-05',['../release-notes.html#libxkbcommon-082--2018-08-05',1,'']]],
  ['2019_2002_2008_26',['libxkbcommon 0.8.3 – 2019-02-08',['../release-notes.html#libxkbcommon-083--2019-02-08',1,'']]],
  ['2019_2002_2022_27',['libxkbcommon 0.8.4 – 2019-02-22',['../release-notes.html#libxkbcommon-084--2019-02-22',1,'']]],
  ['2019_2010_2019_28',['2019 10 19',['../release-notes.html#libxkbcommon-090--2019-10-19',1,'libxkbcommon 0.9.0 – 2019-10-19'],['../release-notes.html#libxkbcommon-091--2019-10-19',1,'libxkbcommon 0.9.1 – 2019-10-19']]],
  ['2020_2001_2018_29',['libxkbcommon 0.10.0 – 2020-01-18',['../release-notes.html#libxkbcommon-0100--2020-01-18',1,'']]],
  ['2020_2009_2005_30',['libxkbcommon 1.0.0 – 2020-09-05',['../release-notes.html#libxkbcommon-100--2020-09-05',1,'']]],
  ['2020_2009_2011_31',['libxkbcommon 1.0.1 – 2020-09-11',['../release-notes.html#libxkbcommon-101--2020-09-11',1,'']]],
  ['2020_2011_2020_32',['libxkbcommon 1.0.2 – 2020-11-20',['../release-notes.html#libxkbcommon-102--2020-11-20',1,'']]],
  ['2020_2011_2023_33',['libxkbcommon 1.0.3 – 2020-11-23',['../release-notes.html#libxkbcommon-103--2020-11-23',1,'']]],
  ['2021_2002_2027_34',['libxkbcommon 1.1.0 – 2021-02-27',['../release-notes.html#libxkbcommon-110--2021-02-27',1,'']]],
  ['2021_2004_2003_35',['libxkbcommon 1.2.0 – 2021-04-03',['../release-notes.html#libxkbcommon-120--2021-04-03',1,'']]],
  ['2021_2004_2007_36',['libxkbcommon 1.2.1 – 2021-04-07',['../release-notes.html#libxkbcommon-121--2021-04-07',1,'']]],
  ['2021_2005_2001_37',['libxkbcommon 1.3.0 – 2021-05-01',['../release-notes.html#libxkbcommon-130--2021-05-01',1,'']]],
  ['2021_2009_2010_38',['libxkbcommon 1.3.1 – 2021-09-10',['../release-notes.html#libxkbcommon-131--2021-09-10',1,'']]],
  ['2022_2002_2004_39',['libxkbcommon 1.4.0 – 2022-02-04',['../release-notes.html#libxkbcommon-140--2022-02-04',1,'']]],
  ['2022_2005_2021_40',['libxkbcommon 1.4.1 – 2022-05-21',['../release-notes.html#libxkbcommon-141--2022-05-21',1,'']]],
  ['2023_2001_2002_41',['libxkbcommon 1.5.0 – 2023-01-02',['../release-notes.html#libxkbcommon-150--2023-01-02',1,'']]],
  ['2023_2010_2008_42',['libxkbcommon 1.6.0 – 2023-10-08',['../release-notes.html#libxkbcommon-160--2023-10-08',1,'']]],
  ['2024_2003_2024_43',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.7.0&quot;&gt;1.7.0&lt;/a&gt; – 2024-03-24',['../release-notes.html#libxkbcommon-170--2024-03-24',1,'']]],
  ['2025_2002_2004_44',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.8.0&quot;&gt;1.8.0&lt;/a&gt; – 2025-02-04',['../release-notes.html#libxkbcommon-180--2025-02-04',1,'']]],
  ['2025_2003_2012_45',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.8.1&quot;&gt;1.8.1&lt;/a&gt; – 2025-03-12',['../release-notes.html#libxkbcommon-181--2025-03-12',1,'']]],
  ['2025_2004_2026_46',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.0&quot;&gt;1.9.0&lt;/a&gt; – 2025-04-26',['../release-notes.html#libxkbcommon-190--2025-04-26',1,'']]],
  ['2025_2005_2002_47',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.1&quot;&gt;1.9.1&lt;/a&gt; – 2025-05-02',['../release-notes.html#libxkbcommon-191--2025-05-02',1,'']]],
  ['2025_2005_2007_48',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.2&quot;&gt;1.9.2&lt;/a&gt; – 2025-05-07',['../release-notes.html#libxkbcommon-192--2025-05-07',1,'']]],
  ['2025_2005_2021_49',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.10.0&quot;&gt;1.10.0&lt;/a&gt; – 2025-05-21',['../release-notes.html#libxkbcommon-1100--2025-05-21',1,'']]],
  ['2025_2008_2008_50',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.11.0&quot;&gt;1.11.0&lt;/a&gt; – 2025-08-08',['../release-notes.html#libxkbcommon-1110--2025-08-08',1,'']]],
  ['2025_2010_2010_51',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.0&quot;&gt;1.12.0&lt;/a&gt; – 2025-10-10',['../release-notes.html#libxkbcommon-1120--2025-10-10',1,'']]],
  ['2025_2010_2017_52',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.1&quot;&gt;1.12.1&lt;/a&gt; – 2025-10-17',['../release-notes.html#libxkbcommon-1121--2025-10-17',1,'']]],
  ['2025_2010_2020_53',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.2&quot;&gt;1.12.2&lt;/a&gt; – 2025-10-20',['../release-notes.html#libxkbcommon-1122--2025-10-20',1,'']]],
  ['2025_2010_2029_54',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.3&quot;&gt;1.12.3&lt;/a&gt; – 2025-10-29',['../release-notes.html#libxkbcommon-1123--2025-10-29',1,'']]],
  ['203_20–_20invalid_20include_20statement_55',['XKB-203 – Invalid include statement',['../error-index.html#XKB-203',1,'']]],
  ['206_20–_20invalid_20modmap_20entry_56',['XKB-206 – Invalid modmap entry',['../error-index.html#XKB-206',1,'']]],
  ['21_57',['21',['../release-notes.html#libxkbcommon-141--2022-05-21',1,'libxkbcommon 1.4.1 – 2022-05-21'],['../release-notes.html#libxkbcommon-1100--2025-05-21',1,'libxkbcommon <a href="https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.10.0">1.10.0</a> – 2025-05-21']]],
  ['22_58',['22',['../release-notes.html#libxkbcommon-032--2013-11-22',1,'libxkbcommon 0.3.2 – 2013-11-22'],['../release-notes.html#libxkbcommon-084--2019-02-22',1,'libxkbcommon 0.8.4 – 2019-02-22']]],
  ['23_59',['libxkbcommon 1.0.3 – 2020-11-23',['../release-notes.html#libxkbcommon-103--2020-11-23',1,'']]],
  ['237_20–_20unsupported_20group_20index_60',['XKB-237 – Unsupported group index',['../error-index.html#XKB-237',1,'']]],
  ['239_20–_20conflicting_20key_20type_20level_20names_61',['XKB-239 – Conflicting key type level names',['../error-index.html#XKB-239',1,'']]],
  ['24_62',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.7.0&quot;&gt;1.7.0&lt;/a&gt; – 2024-03-24',['../release-notes.html#libxkbcommon-170--2024-03-24',1,'']]],
  ['254_20–_20invalid_20set_20default_20statement_63',['XKB-254 – Invalid set default statement',['../error-index.html#XKB-254',1,'']]],
  ['26_64',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.9.0&quot;&gt;1.9.0&lt;/a&gt; – 2025-04-26',['../release-notes.html#libxkbcommon-190--2025-04-26',1,'']]],
  ['266_20–_20conflicting_20key_20type_20map_20entry_65',['XKB-266 – Conflicting key type map entry',['../error-index.html#XKB-266',1,'']]],
  ['27_66',['27',['../release-notes.html#libxkbcommon-041--2014-03-27',1,'libxkbcommon 0.4.1 – 2014-03-27'],['../release-notes.html#libxkbcommon-110--2021-02-27',1,'libxkbcommon 1.1.0 – 2021-02-27']]],
  ['286_20–_20undefined_20key_20type_67',['XKB-286 – Undefined key type',['../error-index.html#XKB-286',1,'']]],
  ['29_68',['libxkbcommon &lt;a href=&quot;https://github.com/xkbcommon/libxkbcommon/tree/xkbcommon-1.12.3&quot;&gt;1.12.3&lt;/a&gt; – 2025-10-29',['../release-notes.html#libxkbcommon-1123--2025-10-29',1,'']]]
];
